@@ -2,6 +2,7 @@
 from molgraph.layers.gnn_layer import GNNLayer
 from molgraph.layers.gnn_input_layer import GNNInputLayer
 from molgraph.layers.gnn_input import GNNInput
+from molgraph.layers.gnn import GNN
 
 from molgraph.layers.attentional.gatv2_conv import GATv2Conv
 from molgraph.layers.attentional.gat_conv import GATConv
@@ -27,6 +28,7 @@ from molgraph.layers.readout.set_gather import SetGatherReadout
 from molgraph.layers.readout.transformer_encoder import TransformerEncoderReadout
 from molgraph.layers.readout.node_readout import NodeReadout
 from molgraph.layers.readout.attentive_fp_readout import AttentiveFPReadout
+from molgraph.layers.readout.super_node_readout import SuperNodeReadout
 
 # positional encoding
 from molgraph.layers.positional_encoding.laplacian import LaplacianPositionalEncoding
@@ -60,6 +62,7 @@ from molgraph.layers.preprocessing.dropout import EdgeDropout
 from molgraph.layers.preprocessing.masking import FeatureMasking
 from molgraph.layers.preprocessing.masking import NodeFeatureMasking
 from molgraph.layers.preprocessing.masking import EdgeFeatureMasking
+from molgraph.layers.preprocessing.update_field import UpdateField 
 
 # layer ops
 from molgraph.layers import gnn_ops as ops # alias
