@@ -1,11 +1,11 @@
 import tensorflow as tf
 from tensorflow import keras
 
-from keras import layers
-from keras import initializers
-from keras import regularizers
-from keras import constraints
-from keras import activations
+from tensorflow.keras import layers
+from tensorflow.keras import initializers
+from tensorflow.keras import regularizers
+from tensorflow.keras import constraints
+from tensorflow.keras import activations
 
 import abc
 
@@ -131,7 +131,7 @@ class GNNLayer(layers.Layer, metaclass=abc.ABCMeta):
         self.units = units
         self._use_bias = use_bias
         if kernel_initializer is None:
-            kernel_initializer = initializers.TruncatedNormal(stddev=0.005)
+            kernel_initializer = 'glorot_uniform'
         self._kernel_initializer = initializers.get(kernel_initializer)
         if bias_initializer is None:
             bias_initializer = initializers.Constant(0.)
