@@ -1,7 +1,7 @@
 import tensorflow as tf
 from tensorflow import keras
-from keras import layers
-from keras import initializers
+from tensorflow.keras import layers
+from tensorflow.keras import initializers
 
 import numpy as np
 
