@@ -1,10 +1,10 @@
 import tensorflow as tf
 from tensorflow import keras
-from keras import layers
-from keras import initializers
-from keras import regularizers
-from keras import constraints
-from keras import activations
+from tensorflow.keras import layers
+from tensorflow.keras import initializers
+from tensorflow.keras import regularizers
+from tensorflow.keras import constraints
+from tensorflow.keras import activations
 
 from molgraph.internal import register_keras_serializable 
 
