@@ -1,5 +1,7 @@
 import tensorflow as tf
 
+import warnings 
+
 from typing import List
 from typing import Optional
 
@@ -43,7 +45,6 @@ class GradientActivationMapping(SaliencyMapping):
     ...
     >>> gam_model = molgraph.models.GradientActivationMapping(
     ...     model=gnn_model,
-    ...     layer_names=['gcn_conv_1', 'gcn_conv_2', 'gcn_conv_3'],
     ...     discard_negative_values=False,
     ... )
     >>> maps = gam_model(esol['test']['x'].separate())
@@ -55,24 +56,25 @@ class GradientActivationMapping(SaliencyMapping):
     def __init__(
         self,
         model,
-        layer_names: List[str] = None,
+        layer_names: List[str] | None = None,
         output_activation: Optional[str] = None,
         discard_negative_values: bool = False,
+        reduce_features: bool = True,
         **kwargs,
     ) -> None:
         super().__init__(model, output_activation, **kwargs)
-        if layer_names is not None:
-            self._layer_names = layer_names
-        else:
-            layer_names = []
-            for layer in model.layers:
-                if isinstance(layer, GNNLayer):
-                    layer_names.append(layer.name)
-            if not layer_names:
-                raise ValueError(
-                    'Could not obtain GNN layer(s).')
-            self._layer_names = layer_names
         self._discard_negative_values = discard_negative_values
+        if layer_names is not None:
+            warnings.warn(
+                (
+                    "`layer_names` is deprecated. All node features will be "
+                    "considered by default."
+                ),
+                DeprecationWarning,
+                stacklevel=2
+            )
+        self._layer_names = layer_names
+        self._reduce_features = reduce_features
 
     def compute_saliency(
         self,
@@ -85,16 +87,22 @@ class GradientActivationMapping(SaliencyMapping):
         with tf.GradientTape() as tape:
 
             for layer in self._model.layers:
-                x = layer(x)
-                if layer.name in self._layer_names:
-                    x_merged = (
-                        x.merge() if isinstance(x.node_feature, tf.RaggedTensor) 
-                        else x)
-                    node_feature = x_merged.node_feature 
-                    if graph_indicator is None:
-                        graph_indicator = x_merged.graph_indicator
-                    features.append(node_feature)
+                
+                if not isinstance(x, GraphTensor):
+                    x = layer(x)
+                    continue 
 
+                if graph_indicator is None:
+                    graph_indicator = x.graph_indicator
+
+                if hasattr(layer, '_taped_call'):
+                    x, taped_features = layer._taped_call(x, tape)
+                    features.extend(taped_features)
+                else:
+                    tape.watch(x.node_feature)
+                    features.append(x.node_feature)
+                    x = layer(x)
+        
             predictions = self._activation(x)
             predictions = self._process_predictions(predictions, y)
 
@@ -106,7 +114,9 @@ class GradientActivationMapping(SaliencyMapping):
         alpha = tf.gather(alpha, graph_indicator)
 
         activation_maps = tf.where(gradients != 0, alpha * features, gradients)
-        activation_maps = tf.reduce_mean(activation_maps, axis=-1)
+
+        if self._reduce_features:
+            activation_maps = tf.reduce_mean(activation_maps, axis=-1)
         
         if self._discard_negative_values:
             activation_maps = tf.nn.relu(activation_maps)
