@@ -4,43 +4,38 @@ from tensorflow import keras
 from typing import Optional
 from typing import Tuple
 
+from molgraph.internal import register_keras_serializable 
+
 from molgraph.tensors.graph_tensor import GraphTensor
 from molgraph.layers.message_passing.mpnn_conv import message_step
 
 
-@keras.utils.register_keras_serializable(package='molgraph')
+@register_keras_serializable(package='molgraph')
 class MPNN(keras.layers.Layer):
 
     '''Message passing neural network (MPNN) with weight tying.
 
-    Implementation is based on Gilmer et al. (2017) [#]_. In contrast to
-    ``MPNNConv``, which performs a single step of message passing, ``MPNN``
-    performs n-steps of message passing. Furthermore, the weights are shared
-    between the message functions of the different steps. And the update
-    functions correspond to a single GRU. This implementation is more similar
-    to Gilmer et al. compared to the stacking of ``MPNNConv`` layers.
+    Implementation is based on Gilmer et al. (2017) [#]_. 
 
-    **Example:**
+    Example usage:
 
     >>> # Obtain GraphTensor
     >>> graph_tensor = molgraph.GraphTensor(
-    ...     data={
-    ...         'edge_dst': [[0, 1], [0, 0, 1, 1, 2, 2]],
-    ...         'edge_src': [[1, 0], [1, 2, 0, 2, 1, 0]],
-    ...         'node_feature': [
-    ...             [[1.0, 0.0], [1.0, 0.0]],
-    ...             [[1.0, 0.0], [1.0, 0.0], [0.0, 1.0]]
-    ...         ],
-    ...     }
+    ...     sizes=[2, 3],
+    ...     node_feature=[[1., 0.], [1., 0.], [1., 0.], [1., 0.], [0., 1.]],
+    ...     edge_feature=[[1., 0.], [0., 1.], [0., 1.], [0., 1.], 
+    ...                   [1., 0.], [0., 1.], [1., 0.], [0., 1.]],
+    ...     edge_src=[1, 0, 3, 4, 2, 4, 3, 2],
+    ...     edge_dst=[0, 1, 2, 2, 3, 3, 4, 4],
     ... )
     >>> # Build Functional model
-    >>> inputs = tf.keras.layers.Input(type_spec=graph_tensor.unspecific_spec)
+    >>> inputs = tf.keras.layers.Input(type_spec=graph_tensor.spec)
     >>> x = molgraph.models.MPNN(units=32, steps=4, name='mpnn')(inputs)
     >>> x = molgraph.layers.SetGatherReadout(name='readout')(x)
     >>> outputs = tf.keras.layers.Dense(10, activation='sigmoid')(x)
     >>> mpnn_classifier = tf.keras.Model(inputs, outputs)
     >>> # Make predictions
-    >>> preds = mpnn_classifier.predict(graph_tensor)
+    >>> preds = mpnn_classifier.predict(graph_tensor, verbose=0)
     >>> preds.shape
     (2, 10)
 
@@ -74,8 +69,8 @@ class MPNN(keras.layers.Layer):
 
     def __init__(
         self,
-        units: Optional[int] = None,
         steps: int = 4,
+        units: Optional[int] = None,
         residual: bool = True,
         dropout: Optional[float] = None,
         message_kwargs: Optional[dict] = None,
@@ -125,14 +120,14 @@ class MPNN(keras.layers.Layer):
         if isinstance(tensor.node_feature, tf.RaggedTensor):
             tensor = tensor.merge()
 
-        edge_dst = tensor.edge_dst
         edge_src = tensor.edge_src
+        edge_dst = tensor.edge_dst
         node_feature_updated = tensor.node_feature
         # MPNN requires edge features, if edge features do not exist,
         # we initialize a ones vector.
-        if not hasattr(tensor, 'edge_feature'):
+        if tensor.edge_feature is None:
             edge_feature = tf.ones(
-                shape=[tf.shape(edge_dst)[0], 1],
+                shape=[tf.shape(edge_src)[0], 1],
                 dtype=node_feature_updated.dtype)
         else:
             edge_feature = tensor.edge_feature
@@ -147,8 +142,8 @@ class MPNN(keras.layers.Layer):
             node_feature_aggregated = message_step(
                 node_feature=node_feature_updated,
                 edge_feature=edge_feature,
-                edge_dst=edge_dst,
                 edge_src=edge_src,
+                edge_dst=edge_dst,
                 projection=self.message_projection)
             # Perform a step of GRU (update function)
             node_feature_updated, _ = self.update_step(
